@@ -88,6 +88,6 @@ print.check_heterogeneity_bias <- function(x, ...) {
   if (is.null(x)) {
     return(0)
   }
-  if (isTRUE(na.rm)) x <- stats::na.omit(x)
+  if (isTRUE(na.rm)) x <- x[!is.na(x)]
   length(unique(x))
 }
