@@ -29,7 +29,7 @@ check_sphericity <- function(x, ...) {
 
 #' @export
 check_sphericity.default <- function(x, ...) {
-  stop("Test not supported yet for object of class ", class(x)[1])
+  insight::format_error(paste0("Test not supported yet for object of class `", class(x)[1], "`."))
 }
 
 
@@ -38,7 +38,7 @@ check_sphericity.default <- function(x, ...) {
 
 #' @export
 plot.check_sphericity <- function(x, ...) {
-  warning(insight::format_message("There is currently no plot() method for `check_sphericity()`."), call. = FALSE)
+  insight::format_warning("There is currently no `plot()` method for `check_sphericity()`.")
 }
 
 
@@ -72,6 +72,7 @@ check_sphericity.Anova.mlm <- function(x, ...) {
     p.val <- 1
   }
 
+  attr(p.val, "data") <- x
   class(p.val) <- c("check_sphericity", "see_check_sphericity", class(p.val))
   p.val
 }
@@ -80,7 +81,7 @@ check_sphericity.Anova.mlm <- function(x, ...) {
 #' @export
 check_sphericity.afex_aov <- function(x, ...) {
   if (length(attr(x, "within")) == 0) {
-    stop("Mauchly Test of Sphericity is only aplicable to ANOVAs with within-subjects factors.")
+    insight::format_error("Mauchly Test of Sphericity is only aplicable to ANOVAs with within-subjects factors.")
   }
 
   check_sphericity.Anova.mlm(x, ...)
@@ -89,9 +90,6 @@ check_sphericity.afex_aov <- function(x, ...) {
 
 #' @export
 check_sphericity.mlm <- function(x, ...) {
-  if (!requireNamespace("car")) {
-    stop("car required for this function to work.")
-  }
-
+  insight::check_if_installed("car")
   check_sphericity.Anova.mlm(car::Anova(x, ...))
 }
