@@ -61,7 +61,9 @@ item_reliability <- function(x, standardize = FALSE, digits = 3) {
     cronbachDeleted <- sapply(seq_len(ncol(x)), function(i) cronbachs_alpha(x[, -i]))
 
     # calculate corrected total-item correlation
-    totalCorr <- sapply(seq_len(ncol(x)), function(i) stats::cor(x[, i], apply(x[, -i], 1, sum), use = "pairwise.complete.obs"))
+    totalCorr <- sapply(seq_len(ncol(x)), function(i) {
+      stats::cor(x[, i], apply(x[, -i], 1, sum), use = "pairwise.complete.obs")
+    })
 
     ret.df <- data.frame(
       term = df.names,
@@ -70,7 +72,7 @@ item_reliability <- function(x, standardize = FALSE, digits = 3) {
       stringsAsFactors = FALSE
     )
   } else {
-    warning("Data frame needs at least three columns for reliability-test.", call. = FALSE)
+    insight::format_warning("Data frame needs at least three columns for reliability-test.")
   }
 
   ret.df
