@@ -16,23 +16,23 @@
 #'   null model.
 #'
 #' @details `method = "Gelman-Hill"` (or `"gelman_hill"`) computes the
-#'   PCP based on the proposal from \cite{Gelman and Hill 2017, 99}, which is
+#'   PCP based on the proposal from _Gelman and Hill 2017, 99_, which is
 #'   defined as the proportion of cases for which the deterministic prediction
 #'   is wrong, i.e. the proportion where the predicted probability is above 0.5,
-#'   although y=0 (and vice versa) (see also \cite{Herron 1999, 90}).
-#'   \cr \cr
+#'   although y=0 (and vice versa) (see also _Herron 1999, 90_).
+#'
 #'   `method = "Herron"` (or `"herron"`) computes a modified version
-#'   of the PCP (\cite{Herron 1999, 90-92}), which is the sum of predicted
+#'   of the PCP (_Herron 1999, 90-92_), which is the sum of predicted
 #'   probabilities, where y=1, plus the sum of 1 - predicted probabilities,
 #'   where y=0, divided by the number of observations. This approach is said to
 #'   be more accurate.
-#'   \cr \cr
+#'
 #'   The PCP ranges from 0 to 1, where values closer to 1 mean that the model
 #'   predicts the outcome better than models with an PCP closer to 0. In general,
 #'   the PCP should be above 0.5 (i.e. 50\%), the closer to one, the better.
 #'   Furthermore, the PCP of the full model should be considerably above
 #'   the null model's PCP.
-#'   \cr \cr
+#'
 #'   The likelihood-ratio test indicates whether the model has a significantly
 #'   better fit than the null-model (in such cases, p < 0.05).
 #'
@@ -40,7 +40,6 @@
 #' @references
 #' - Herron, M. (1999). Postestimation Uncertainty in Limited Dependent
 #'   Variable Models. Political Analysis, 8, 83–98.
-#'
 #' - Gelman, A., and Hill, J. (2007). Data analysis using regression and
 #'   multilevel/hierarchical models. Cambridge; New York: Cambridge University
 #'   Press, 99.
@@ -64,7 +63,7 @@ performance_pcp <- function(model,
   mi <- insight::model_info(model, verbose = verbose)
 
   if (!mi$is_binomial) {
-    stop("`performance_pcp()` only works for models with binary outcome.", call. = FALSE)
+    insight::format_error("`performance_pcp()` only works for models with binary outcome.")
   }
 
   resp <- insight::get_response(model, verbose = verbose)
@@ -81,11 +80,7 @@ performance_pcp <- function(model,
     weights = stats::weights(model)
   ))
 
-  if (method %in% c("Herron", "herron")) {
-    .pcp_herron(model, m0, ci, verbose = verbose)
-  } else {
-    .pcp_gelman_hill(model, m0, ci, verbose = verbose)
-  }
+  .performance_pcp(model, m0, ci, method = method, verbose = verbose)
 }
 
 
@@ -118,7 +113,7 @@ print.performance_pcp <- function(x, digits = 2, ...) {
 as.data.frame.performance_pcp <- function(x, row.names = NULL, ...) {
   data.frame(
     "Model" = c("full", "null"),
-    "Estimate" =  c(x$pcp_model, x$pcp_m0),
+    "Estimate" = c(x$pcp_model, x$pcp_m0),
     "CI_low" = c(x$model_ci_low, x$null_ci_low),
     "CI_high" = c(x$model_ci_high, x$null_ci_high),
     "Chisq" = c(NA, x$lrt_chisq),
@@ -134,7 +129,7 @@ as.data.frame.performance_pcp <- function(x, row.names = NULL, ...) {
 
 # utilities --------------------------------------
 
-.pcp_herron <- function(model, m0, ci, verbose = TRUE) {
+.performance_pcp <- function(model, m0, ci, method, verbose = TRUE) {
   y_full <- .recode_to_zero(insight::get_response(model, verbose = verbose))
   y_null <- .recode_to_zero(insight::get_response(m0, verbose = verbose))
 
@@ -144,46 +139,13 @@ as.data.frame.performance_pcp <- function(x, row.names = NULL, ...) {
   pr_full <- stats::predict(model, type = "response")
   pr_null <- stats::predict(m0, type = "response")
 
-  pcp_full <- (sum(1 - pr_full[y_full == 0]) + sum(pr_full[y_full == 1])) / n_full
-  pcp_null <- (sum(1 - pr_null[y_null == 0]) + sum(pr_null[y_null == 1])) / n_null
-
-  lrt.p <- 1 - stats::pchisq(
-    q = model$null.deviance - model$deviance,
-    df = model$df.null - model$df.residual,
-    lower.tail = TRUE
-  )
-
-  lrt.chisq <- 2 * abs(insight::get_loglikelihood(model, verbose = verbose) - insight::get_loglikelihood(m0, verbose = verbose))
-
-  structure(
-    class = "performance_pcp",
-    list(
-      pcp_model = pcp_full,
-      model_ci_low = pcp_full - stats::qnorm((1 + ci) / 2) * sqrt(pcp_full * (1 - pcp_full) / n_full),
-      model_ci_high = pcp_full + stats::qnorm((1 + ci) / 2) * sqrt(pcp_full * (1 - pcp_full) / n_full),
-      pcp_m0 = pcp_null,
-      null_ci_low = pcp_null - stats::qnorm((1 + ci) / 2) * sqrt(pcp_null * (1 - pcp_null) / n_null),
-      null_ci_high = pcp_null + stats::qnorm((1 + ci) / 2) * sqrt(pcp_null * (1 - pcp_null) / n_null),
-      lrt_chisq = as.vector(lrt.chisq),
-      lrt_df_error = model$df.null - model$df.residual,
-      lrt_p = lrt.p
-    )
-  )
-}
-
-
-.pcp_gelman_hill <- function(model, m0, ci, verbose = TRUE) {
-  y_full <- .recode_to_zero(insight::get_response(model, verbose = verbose))
-  y_null <- .recode_to_zero(insight::get_response(m0, verbose = verbose))
-
-  n_full <- suppressWarnings(insight::n_obs(model))
-  n_null <- suppressWarnings(insight::n_obs(m0))
-
-  pr_full <- stats::predict(model, type = "response")
-  pr_null <- stats::predict(m0, type = "response")
-
-  pcp_full <- 1 - mean((pr_full > .5 & y_full == 0) | (pr_full <= .5 & y_full == 1))
-  pcp_null <- 1 - mean((pr_null > .5 & y_null == 0) | (pr_null <= .5 & y_null == 1))
+  if (tolower(method) == "herron") {
+    pcp_full <- (sum(1 - pr_full[y_full == 0]) + sum(pr_full[y_full == 1])) / n_full
+    pcp_null <- (sum(1 - pr_null[y_null == 0]) + sum(pr_null[y_null == 1])) / n_null
+  } else {
+    pcp_full <- 1 - mean((pr_full > .5 & y_full == 0) | (pr_full <= .5 & y_full == 1))
+    pcp_null <- 1 - mean((pr_null > .5 & y_null == 0) | (pr_null <= .5 & y_null == 1))
+  }
 
   lrt.p <- 1 - stats::pchisq(
     q = model$null.deviance - model$deviance,
