@@ -1,4 +1,4 @@
-if (requiet("testthat") && requiet("performance") && requiet("glmmTMB")) {
+if (requiet("testthat") && requiet("performance") && requiet("glmmTMB") && getRversion() >= "4.0.0") {
   data(Salamanders)
   m1 <- glmmTMB(count ~ spp + mined + (1 | site),
     ziformula = ~spp,
@@ -22,7 +22,7 @@ if (requiet("testthat") && requiet("performance") && requiet("glmmTMB")) {
 
   m2 <- glmmTMB(
     count ~ spp + mined + cover + (1 | site),
-    ziformula =  ~ spp + mined + cover,
+    ziformula = ~ spp + mined + cover,
     family = nbinom2,
     data = Salamanders
   )
