@@ -23,24 +23,37 @@ if (.runThisTest && !osx) {
     test_that("icc", {
       expect_equal(
         icc(m1),
-        structure(list(
+        data.frame(
           ICC_adjusted = 0.910433109183341, ICC_conditional = 0.310947768161385,
           ICC_unadjusted = 0.310947768161385
-        ), class = "icc"),
-        tolerance = 1e-3
+        ),
+        tolerance = 1e-3,
+        ignore_attr = TRUE
       )
     })
 
+
+    # bootstrapped CIs ------------
+    m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
+    set.seed(123)
+    out <- icc(m, ci = 0.95)
+    test_that("icc, CI", {
+      expect_equal(out$ICC_adjusted, c(0.72166, 0.52239, 0.84024), tolerance = 1e-3)
+      expect_equal(out$ICC_unadjusted, c(0.52057, 0.32429, 0.67123), tolerance = 1e-3)
+    })
+
+
     m2 <- insight::download_model("stanreg_lmerMod_1")
 
     test_that("icc", {
       expect_equal(
         icc(m2),
-        structure(list(
+        data.frame(
           ICC_adjusted = 0.399303562702568, ICC_conditional = 0.216907586891627,
           ICC_unadjusted = 0.216907586891627
-        ), class = "icc"),
-        tolerance = 1e-3
+        ),
+        tolerance = 1e-3,
+        ignore_attr = TRUE
       )
     })
 
@@ -59,11 +72,12 @@ if (.runThisTest && !osx) {
       set.seed(123)
       expect_equal(
         icc(m3),
-        structure(list(
+        data.frame(
           ICC_adjusted = 0.930217931275196, ICC_conditional = 0.771475122370036,
           ICC_unadjusted = 0.771475122370036
-        ), class = "icc"),
-        tolerance = 0.05
+        ),
+        tolerance = 0.05,
+        ignore_attr = TRUE
       )
     })
 
