@@ -39,12 +39,20 @@ if (.runThisTest &&
     expect_equal(perf$R2, 0.8262673, tolerance = 1e-3)
     expect_equal(perf$R2_adjusted, 0.7982615, tolerance = 1e-3)
     expect_equal(perf$ELPD, -78.59823, tolerance = 1e-3)
+    expect_equal(colnames(perf), c(
+      "ELPD", "ELPD_SE", "LOOIC", "LOOIC_SE", "WAIC", "R2", "R2_adjusted",
+      "RMSE", "Sigma"
+    ))
 
     model <- insight::download_model("brms_mixed_4")
     expect_warning(perf <- model_performance(model))
     expect_equal(perf$R2, 0.954538, tolerance = 1e-3)
     expect_equal(perf$R2_adjusted, 0.9529004, tolerance = 1e-3)
     expect_equal(perf$ELPD, -70.40493, tolerance = 1e-3)
+    expect_equal(colnames(perf), c(
+      "ELPD", "ELPD_SE", "LOOIC", "LOOIC_SE", "WAIC", "R2", "R2_marginal",
+      "R2_adjusted", "R2_adjusted_marginal", "ICC", "RMSE", "Sigma"
+    ))
 
     model <- insight::download_model("brms_ordinal_1")
     perf <- suppressWarnings(model_performance(model))
