@@ -1,4 +1,4 @@
-if (require("testthat") && require("performance") && require("ISLR") && require("bayestestR")) {
+if (requiet("testthat") && requiet("performance") && requiet("ISLR") && requiet("bayestestR")) {
   data(Smarket, package = "ISLR")
 
   m1 <- glm(am ~ vs + wt, family = binomial(), data = mtcars)
